<template>
  <a-modal title='MQTT配置' :width='600' :visible='visible' :maskClosable='false' :confirmLoading='confirmLoading'
           :okButtonProps='{ props: {disabled: disableSubmit} }' @ok='handleOk' @cancel='handleCancel' cancelText='关闭'>
    <a-spin :spinning='confirmLoading'>
      <a-form :form='form'>

        <a-row :gutter='24'>
          <a-col :span='12'>
            <a-form-item label='服务端地址' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入服务端地址' allow-clear
                       :maxLength='15' v-decorator="['address', validatorRules.address]" />
            </a-form-item>
          </a-col>
          <a-col :span='12'>
            <a-form-item label='客户端ID' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入客户端ID' allow-clear
                       :maxLength='20' v-decorator="[ 'clintId', validatorRules.clintId]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='24'>
          <a-col :span='12'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='端口'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入端口' allow-clear
                       v-decorator="['port', validatorRules.port]" />
            </a-form-item>
          </a-col>
          <a-col :span='12'>
            <a-form-item label='用户名' :labelCol='labelCol' :wrapperCol='wrapperCol'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入用户名' allow-clear
                       :maxLength='6' v-decorator="[ 'userName', validatorRules.userName]" />
            </a-form-item>
          </a-col>
        </a-row>
        <a-row :gutter='24'>
          <a-col :span='12'>
            <a-form-item :labelCol='labelCol' :wrapperCol='wrapperCol' label='密码'>
              <a-input :disabled='disableSubmit' :readOnly='disableSubmit' placeholder='请输入密码' allow-clear
                       v-decorator="['userPassword', validatorRules.userPassword]" />
            </a-form-item>
          </a-col>
        </a-row>
      </a-form>
    </a-spin>
    <template slot='footer' v-if='disableSubmit == false'>
      <a-button :style="{ marginRight: '8px' }" @click='handleCancel'>关闭</a-button>
      <a-button @click='handleOk' type='primary'>确定</a-button>
    </template>
  </a-modal>
</template>

<script>
import pick from 'lodash.pick'
import { httpAction } from '@/api/manage'

let validatorCodeTimer = null

export default {
  name: 'MqttModel',
  data() {
    return {
      visible: false,
      model: {},
      serverDeploy: {},
      labelCol: {
        xs: { span: 24 },
        sm: { span: 7 }
      },
      wrapperCol: {
        xs: { span: 24 },
        sm: { span: 14 }
      },
      confirmLoading: false,
      form: this.$form.createForm(this),
      validatorRules: {
        address: {
          rules: [{
            required: true,
            message: '请输入服务端地址'
          }]
        },
        clintId: {
          rules: [{
            required: true,
            message: '请输入客户端ID'
          }]
        },
        port: {
          rules: [{
            required: true,
            message: '请输入端口'
          }]
        },
        userName: {
          rules: [{
            required: true,
            message: '请输入用户名'
          }]
        },
        userPassword: {
          rules: [{
            required: true,
            message: '请输入密码'
          }]
        }

      },
      url: {
        add: '/serve/deploy/add/mqtt',
        edit: '/serve/deploy/edit/mqtt'
      },
      disableSubmit: false
    }
  },

  methods: {
    add() {
      this.edit({})
    },
    edit(record) {
      this.form.resetFields()
      this.serverDeploy = Object.assign({}, record)
      this.model = Object.assign({}, this.serverDeploy.mqttDeploy)
      this.visible = true
      this.$nextTick(() => {
        this.form.setFieldsValue(pick(this.model, 'serverName', 'address', 'clintId', 'port', 'userName', 'userPassword'))
      })
    },
    close() {
      this.$emit('close')
      this.visible = false
    },
    handleOk() {
      const that = this
      // 触发表单验证
      this.form.validateFields((err, values) => {
        if (!err) {
          that.confirmLoading = true
          let formData = Object.assign(this.model, values)
          let obj
          if (!this.model.id) {
            formData.projectClassifyId = this.serverDeploy.projectClassifyId
            formData.serverDeployId = this.serverDeploy.id
            obj = httpAction(this.url.add, formData, 'post')
          } else {
            obj = httpAction(this.url.edit, formData, 'put')
          }
          obj.then((res) => {
            if (res.success) {
              that.$message.success(res.message)
              that.$emit('ok', res.result)
            } else {
              that.$message.warning(res.message)
            }
          }).finally(() => {
            that.confirmLoading = false
            that.close()
          })
        }
      })
    },
    handleCancel() {
      this.close()
    }
  }
}
</script>

<style scoped>
.ant-btn {
  padding: 0 10px;
  margin-left: 3px;
}

.ant-form-item-control {
  line-height: 0px;
}

/** 主表单行间距 */
.ant-form .ant-form-item {
  margin-bottom: 10px;
}

/** Tab页面行间距 */
.ant-tabs-content .ant-form-item {
  margin-bottom: 0px;
}
</style>
